==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/RectChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RectChangedEventArgsDescription } from "./RectChangedEventArgsDescription";
/**
 * @hidden
 */
export let RectChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RectChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RectChangedEventArgsDescriptionMetadata.a == null) {
                RectChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RectChangedEventArgsDescriptionMetadata.c(RectChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(RectChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(RectChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldRect", "Rect");
            a.item("NewRect", "Rect");
        }
        static d(a) {
            RectChangedEventArgsDescriptionMetadata.b(a);
            a.ad("RectChangedEventArgs", () => new RectChangedEventArgsDescription());
            a.ac("RectChangedEventArgs", RectChangedEventArgsDescriptionMetadata.a);
        }
    }
    RectChangedEventArgsDescriptionMetadata.$t = markType(RectChangedEventArgsDescriptionMetadata, 'RectChangedEventArgsDescriptionMetadata');
    RectChangedEventArgsDescriptionMetadata.a = null;
    return RectChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/RectChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RectChangedEventArgsDescription } from "./RectChangedEventArgsDescription";
/**
 * @hidden
 */
export let RectChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RectChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RectChangedEventArgsDescriptionMetadata.a == null) {
                RectChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RectChangedEventArgsDescriptionMetadata.c(RectChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(RectChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(RectChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldRect", "Rect");
            a.item("NewRect", "Rect");
        }
        static d(a) {
            RectChangedEventArgsDescriptionMetadata.b(a);
            a.ae("RectChangedEventArgs", () => new RectChangedEventArgsDescription());
            a.ad("RectChangedEventArgs", RectChangedEventArgsDescriptionMetadata.a);
        }
    }
    RectChangedEventArgsDescriptionMetadata.$t = markType(RectChangedEventArgsDescriptionMetadata, 'RectChangedEventArgsDescriptionMetadata');
    RectChangedEventArgsDescriptionMetadata.a = null;
    return RectChangedEventArgsDescriptionMetadata;
})();
